@@ -2,6 +2,7 @@ import sys
 from tdf_tools.pipelines.module import Module
 from tdf_tools.pipelines.translate import Translate
 from tdf_tools.pipelines.router import Router
+from tdf_tools.pipelines.fix_header import FixHeader
 from tdf_tools.pipelines.package import Package
 
 from tdf_tools.pipelines.git import Git
@@ -18,6 +19,7 @@ class Pipeline:
         self.translate = Translate()
         self.package = Package()
         self.router = Router()
+        self.fixHeader = FixHeader()
 
     def upgrade(self):
         """
