@@ -1,13 +1,13 @@
 from tdf_tools.tools.cli.project_cli import ProjectCLI
+from tdf_tools.tools.cmd import Cmd
 from tdf_tools.tools.config.config import CLIJsonConfig
-from tdf_tools.tools.print import Print
-from tdf_tools.tools.shell_dir import ShellDir
+from tdf_tools.tools.shell_dir import ProjectType, ShellDir
 from tdf_tools.tools.vscode.vscode import VsCodeManager
 
 
 class Module:
     """
-    模块相关工具： tdf_tools module -h 查看详情
+    模块相关工具： tl module -h 查看详情
     """
 
     def __init__(self):
@@ -26,7 +26,13 @@ class Module:
         修改initial_config.json文件后，执行该命令，更新依赖
         """
         ShellDir.dirInvalidate()
-        self.__cli.cliDeps()
+        ShellDir.goInShellDir()
+        projectType = ShellDir.getProjectType()
+        if projectType == ProjectType.FLUTTER:
+            self.__cli.cliDeps()
+        elif projectType == ProjectType.IOS:
+            ios_arg = ["bundle", "exec", "pod", "bin", "batch", "clone"]
+            Cmd.runAndPrint(ios_arg, shell=False)
 
     def open(self):
         """
