@@ -30,13 +30,11 @@ class RouterNode:
 
 class Router:
     """
-    路由相关命令：tdf_tools router -h 查看详情
+    路由相关命令：tl router -h 查看详情
     """
 
     def __init__(self):
         self.__packagesList: list[PackageNode] = []
-        # 备份壳模块路径
-        self.__shellPath = ShellDir.getShellDir()
         # 文档数据
         self.__macDownDataList: list[RouterNode] = []
         # 业务入口页列表
@@ -48,7 +46,7 @@ class Router:
 
     def start(self):
         """
-        tdf_tools router start：会以交互式进行路由操作，对指定的模块执行路由生成和路由注册逻辑
+        tl router start：会以交互式进行路由操作，对指定的模块执行路由生成和路由注册逻辑
         """
         ShellDir.dirInvalidate()
         businessModuleList = self.__router_businessModuleList()
@@ -72,7 +70,7 @@ class Router:
 
     def module(self, name: str):
         """
-        tdf_tools router module [module_name]：对指定的模块执行路由生成和路由注册逻辑
+        tl router module [module_name]：对指定的模块执行路由生成和路由注册逻辑
         """
         ShellDir.dirInvalidate()
         businessModuleList = self.__router_businessModuleList()
@@ -86,7 +84,7 @@ class Router:
 
     def integrate(self):
         """
-        tdf_tools router integrate：对壳进行路由整合
+        tl router integrate：对壳进行路由整合
         """
         ShellDir.dirInvalidate()
         self.__fetch__packagesList()
@@ -132,6 +130,9 @@ class Router:
         # 生成路由文档
         self.__generate_router_doc()
 
+        # 全部生成文件format
+        self.__format__()
+
     # 生成注解描述文件
     def __generator_router_des(self, targetModule):
         Print.title(targetModule + " 模块生成注解描述文件")
@@ -166,10 +167,11 @@ class Router:
             # 存在路由描述文件才进行遍历
             ShellDir.goInShellDir()
             if self.__hasRouterDartFile(packageItem.packagePath):
-                os.chdir(self.__shellPath + "/lib/tz_router/group/")
+                os.chdir(ShellDir.getShellDir() + "/lib/tz_router/group/")
                 os.mkdir(packageItem.packageName)
                 os.chdir(packageItem.packageName)
-                f = open("router_map.dart", "w+")
+                file_name = "router_map.dart"
+                f = open(file_name, "w+")
                 self.__defaultImportCreator(f, "'package:tdf_router/tdf_router.dart';")
 
                 ShellDir.goInShellDir()
@@ -221,7 +223,8 @@ class Router:
         ShellDir.goInShellDir()
         os.chdir("lib/tz_router")
 
-        initF = open("init.dart", "w+")
+        file_name = "init.dart"
+        initF = open(file_name, "w+")
 
         # 生成初始化init文件
         if os.path.exists("group") == False:
@@ -232,10 +235,10 @@ class Router:
         # 添加flutter业务入口页面import
         self.__defaultImportCreator(initF, "'entry/tz_router_entry_page.dart';")
         mapList = []
-        for root, dirs, files in os.walk(nowaPath):
+        for root, _, files in os.walk(nowaPath):
             for file in files:
                 src_file = os.path.join(root, file)
-                if src_file.find("init.dart") != -1:
+                if src_file.find(file_name) != -1:
                     continue
                 if PlatformTools.is_windows():
                     tmpItemFilePath = src_file.split("tz_router")[1]
@@ -269,6 +272,7 @@ class Router:
         initF.close()
 
     # 生成路由入口文件
+
     def __generate_router_entry_files(self):
         Print.title("生成路由入口文件")
         ShellDir.goInShellDir()
@@ -279,7 +283,8 @@ class Router:
 
         os.chdir("entry")
 
-        entryPageF = open("tz_router_entry_page.dart", "w+")
+        file_name = "tz_router_entry_page.dart"
+        entryPageF = open(file_name, "w+")
 
         self.__defaultImportCreator(entryPageF, "'package:flutter/material.dart';")
         self.__defaultImportCreator(entryPageF, "'package:tdf_router/tdf_router.dart';")
@@ -295,120 +300,124 @@ class Router:
         self.__defaultImportCreator(
             entryPageF, "'package:tdf_widgets/title_bar/tdf_title_bar.dart';"
         )
-        self.__defaultImportCreator(
-            entryPageF, "'package:tdf_widgets/background/tdf_native_background.dart';"
-        )
         entryPageF.write(
             """
 
-        @TZRouter(path: '{0}', note: '{1}')
-        class {2} extends StatefulWidget {{
-            final Map params;
+@TZRouter(path: '{0}', note: '{1}')
+class {2} extends StatefulWidget {{
+    final Map params;
 
-            {2}(this.params);
+    {2}(this.params);
 
-            @override
-            _{2}State createState() => _{2}State();
-        }}
+    @override
+    _{2}State createState() => _{2}State();
+}}
 
-        class _{2}State extends State<{2}> {{
-            final TextEditingController routerController = new TextEditingController();
-            final TextEditingController controller = new TextEditingController();
-            final Map<String, String> pageMap = {{
-            {3}
-            }};
+class _{2}State extends State<{2}> {{
+    final TextEditingController routerController = new TextEditingController();
+    final TextEditingController controller = new TextEditingController();
+    final Map<String, String> pageMap = {{
+    {3}
+    }};
 
-            @override
-            Widget build(BuildContext context) {{
-                TDFScreen.init(context);
-                return Scaffold(
-                    backgroundColor: Color(0xffffffff),
-                    appBar: TDFTitleBar(
-                        titleContent: \"{4}\",
-                        backType: TDFTitleBackWidgetType.DEFAULT_BACK,
-                    ),
-                    body: SingleChildScrollView(
-                        child: Column(
-                            children: _getButtonList(),
-                        ),
-                    ),
-                );
-            }}
-
-            List<Widget> _getButtonList() {{
-                List<Widget> list = [];
-                list.add(_routerJumpWidget());
-                list.add(Padding(
-                padding: EdgeInsets.only(top: 20.w),
-                child: TDFButton(
-                    content: \"根据路由跳转\",
-                    bgColor: 0xff0088ff,
-                    contentColor: 0xffffffff,
-                    onClick: () {{
-                    FocusScope.of(context).requestFocus(FocusNode());
-                    TDFRouter.open(routerController.text);
-                    }},
-                ),
-                ));
-                list.add(_searchWidget());
-
-                List<Widget> wrapEntrylist = [];
-                pageMap.forEach((key, value) {{
-                if (key.contains(controller.text)) {{
-                    wrapEntrylist.add(GestureDetector(
-                        onTap: () {{
-                        FocusScope.of(context).requestFocus(FocusNode());
-                        TDFRouter.open(value);
-                        }},
-                        child: ClipRRect(
-                        borderRadius: BorderRadius.all(Radius.circular(3.w)),
-                        child: Container(
-                            color: Colors.blue,
-                            padding: EdgeInsets.only(
-                                left: 7.w, right: 7.w, top: 4.w, bottom: 4.w),
-                            child: Text(
-                            key,
-                            style: TextStyle(fontSize: 13.w),
-                            ),
-                        ),
-                        )));
-                }}
+    @override
+    Widget build(BuildContext context) {{
+        TDFScreen.init(context);
+        return Scaffold(
+            backgroundColor: Color(0xffffffff),
+            appBar: TDFTitleBar(
+                titleContent: \"{4}\",
+                backType: TDFTitleBackWidgetType.DEFAULT_BACK,
+                rightContent: "UI标准化",
+                rightContentColor: 0xff0088ff,
+                rightTextBtnClick: () {{
+                TDFRouter.open("tdf-manager://2dfire.com/ticket/index", urlParams: {{
+                    "app_key": "200800",
+                    "h5url": "http://10.1.16.14:8111/"
                 }});
-                list.add(SizedBox(
-                height: 20.w,
-                ));
-                list.add(Wrap(
-                spacing: 15.w,
-                runSpacing: 10.w,
-                children: wrapEntrylist,
-                ));
-                return list;
-            }}
+                }},
+            ),
+            body: SingleChildScrollView(
+                child: Column(
+                    children: _getButtonList(),
+                ),
+            ),
+        );
+    }}
 
-            Widget _routerJumpWidget() {{
-                return TextField(
-                controller: routerController,
-                autofocus: false,
-                decoration: InputDecoration(hintText: "输入页面路由"),
-                onChanged: (value) {{
-                    setState(() {{}});
-                    }},
-                );
-            }}
-
-            Widget _searchWidget() {{
-                return TextField(
-                    controller: controller,
-                    autofocus: false,
-                    decoration: InputDecoration(hintText: "筛选"),
-                    onChanged: (value) {{
-                        setState(() {{}});
-                    }},
-                );
-            }}
-            
+    List<Widget> _getButtonList() {{
+        List<Widget> list = [];
+        list.add(_routerJumpWidget());
+        list.add(Padding(
+        padding: EdgeInsets.only(top: 20.w),
+        child: TDFButton(
+            content: \"根据路由跳转\",
+            bgColor: 0xff0088ff,
+            contentColor: 0xffffffff,
+            onClick: () {{
+            FocusScope.of(context).requestFocus(FocusNode());
+            TDFRouter.open(routerController.text);
+            }},
+        ),
+        ));
+        list.add(_searchWidget());
 
+        List<Widget> wrapEntrylist = [];
+        pageMap.forEach((key, value) {{
+        if (key.contains(controller.text)) {{
+            wrapEntrylist.add(GestureDetector(
+                onTap: () {{
+                FocusScope.of(context).requestFocus(FocusNode());
+                TDFRouter.open(value);
+                }},
+                child: ClipRRect(
+                borderRadius: BorderRadius.all(Radius.circular(3.w)),
+                child: Container(
+                    color: Colors.blue,
+                    padding: EdgeInsets.only(
+                        left: 7.w, right: 7.w, top: 4.w, bottom: 4.w),
+                    child: Text(
+                    key,
+                    style: TextStyle(fontSize: 13.w),
+                    ),
+                ),
+                )));
         }}
+        }});
+        list.add(SizedBox(
+        height: 20.w,
+        ));
+        list.add(Wrap(
+        spacing: 15.w,
+        runSpacing: 10.w,
+        children: wrapEntrylist,
+        ));
+        return list;
+    }}
+
+    Widget _routerJumpWidget() {{
+        return TextField(
+        controller: routerController,
+        autofocus: false,
+        decoration: InputDecoration(hintText: "输入页面路由"),
+        onChanged: (value) {{
+            setState(() {{}});
+            }},
+        );
+    }}
+
+    Widget _searchWidget() {{
+        return TextField(
+            controller: controller,
+            autofocus: false,
+            decoration: InputDecoration(hintText: "筛选"),
+            onChanged: (value) {{
+                setState(() {{}});
+            }},
+        );
+    }}
+    
+}}
         """.format(
                 self.__entryPagePath,
                 self.__entryPageNote,
@@ -491,6 +500,11 @@ class Router:
 
         f.close()
 
+    # 对所有tz_router目录下的文件执行format
+    def __format__(self):
+        ShellDir.goInShellLibDir()
+        os.system("dart format ./tz_router")
+
     # 获取远程代码路径
     def __getRemoteCodePackagePath(self, line: str) -> PackageNode:
         packageName = line.split(":file://")[0]
@@ -675,7 +689,7 @@ class Router:
             cofig_item = __module_config.get_item(item)
             if (
                 cofig_item.type == ModuleItemType.Lib
-                or cofig_item == ModuleItemType.Module
+                or cofig_item.type == ModuleItemType.Module
             ):
                 businessModuleList.append(item)
         return businessModuleList
